django-flashpolicies 1.4 — django-flashpolicies v1.4 documentation

### Navigation

- index
- modules |
- next |
- django-flashpolicies v1.4 documentation »

# django-flashpolicies 1.4

This application enables simple Flash cross-domain policies (which are required for Flash content to access information across domains) for Django-powered sites. Cross-domain policies are represented by an XML file format, and this application generates and serves the appropriate XML.

In the simplest case, you’ll simply set up one URL pattern, pointing the URL `/crossdomain.xml` to the view `flashpolicies.views.simple()` and passing a list of domains from which you want to allow access. For example, to allow access from Flash content served from `media.example.com`, you could place the following in the root URLconf of your Django site:

    url(r'^crossdomain.xml$',
        'flashpolicies.views.simple',
        {'domains': ['media.example.com']}),

## Documentation contents

- Installation guide
- Views for serving cross-domain policies
- Utilities for generating cross-domain policy files

See also

- Adobe’s recommendations for use of Flash cross-domain policies
- Google doctype article on Flash cross-domain policies

### Navigation

- index
- modules |
- next |
- django-flashpolicies v1.4 documentation »